bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGammaISO.add_plate_axis
==============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGammaISO.add_plate_axis